Module access_keys

Module access_keys 

Functions

assert_access_key_expiration
Validates access key expiration settings.
assert_controllers
Asserts that the access key IDs are not anonymous and not revoked.
assert_max_number_of_access_keys
Asserts that the number of access keys does not exceed the maximum allowed.
delete_access_keys
Removes specified access keys from the set.
filter_admin_access_keys
Filters the set of access keys, returning only those with administrative scope.
init_admin_access_keys
Initializes a set of access keys with default administrative scope.
into_access_key_ids
Converts the access keys set into a vector of access key IDs.
is_admin_controller
Checks if an id is an admin access key and a controller has known by the Internet Computer.
is_console
Checks if the id is the console.
is_observatory
Checks if the id is the observatory.
is_self
Checks if an id (e.g. a caller, a user or a principal) is the canister itself.
is_valid_access_key
Checks if an id is a non-expired access key regardless of scope (admin, write, or submit).
is_write_access_key
Checks if an id is a non-expired access key with admin or write scope (permissions).
set_access_keys
Sets or updates access keys with specified data.