assert_max_number_of_access_keys

Function assert_max_number_of_access_keys 

pub fn assert_max_number_of_access_keys(
    current_access_keys: &AccessKeys,
    access_keys_ids: &[AccessKeyId],
    scope: &AccessKeyScope,
    max_access_keys: Option<usize>,
) -> Result<(), String>
Asserts that the number of access keys does not exceed the maximum allowed.

Arguments

  • current_access_keys: Reference to the current set of access keys.
  • access_keys_ids: Slice of AccessKeyId representing the access keys to be added.
  • scope: The scope of the new access key to be added.
  • max_access_keys: Optional custom maximum number of allowed access keys.

Returns

Ok(()) if the operation is successful, or Err(String) if the maximum is exceeded.