UnwrapOrTrapResult

Trait UnwrapOrTrapResult 

pub trait UnwrapOrTrapResult<T> {
    // Required method
    fn unwrap_or_trap_result(self) -> T;
}
Unwraps a Result<Option<T>, E> into T, trapping on either failure.

Required Methods

fn unwrap_or_trap_result(self) -> T

Returns the contained Ok(Some(T)) value, or traps.

Panics

Traps the canister execution with the error message if the Result is Err, or with a default message if the Option is None.

Implementations on Foreign Types

Source

impl<T, E: Display> UnwrapOrTrapResult<T> for Result<Option<T>, E>

Implementors