Functions
- assert_
access_ key_ expiration - Validates access key expiration settings.
- assert_
controllers - Asserts that the access key IDs are not anonymous and not revoked.
- assert_
max_ number_ of_ access_ keys - Asserts that the number of access keys does not exceed the maximum allowed.
- delete_
access_ keys - Removes specified access keys from the set.
- filter_
admin_ access_ keys - Filters the set of access keys, returning only those with administrative scope.
- init_
admin_ access_ keys - Initializes a set of access keys with default administrative scope.
- into_
access_ key_ ids - Converts the access keys set into a vector of access key IDs.
- is_
admin_ controller - Checks if an id is an admin access key and a controller has known by the Internet Computer.
- is_
console - Checks if the id is the console.
- is_
observatory - Checks if the id is the observatory.
- is_self
- Checks if an id (e.g. a caller, a user or a principal) is the canister itself.
- is_
valid_ access_ key - Checks if an id is a non-expired access key regardless of scope (admin, write, or submit).
- is_
write_ access_ key - Checks if an id is a non-expired access key with admin or write scope (permissions).
- set_
access_ keys - Sets or updates access keys with specified data.